@@ -235,8 +235,10 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
   const gchar *level = NULL;
   const gchar *uuid = NULL;
   const gchar *name = NULL;
+  const gchar *devfile = NULL;
   gchar *sync_action = NULL;
   gchar *sync_completed = NULL;
+  gchar *consistency_policy = NULL;
   gchar *bitmap_location = NULL;
   guint degraded = 0;
   guint64 chunk_size = 0;
@@ -316,7 +318,10 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
           degraded = udisks_linux_device_read_sysfs_attr_as_int (raid_device, "md/degraded", NULL);
           sync_action = udisks_linux_device_read_sysfs_attr (raid_device, "md/sync_action", NULL);
           sync_completed = udisks_linux_device_read_sysfs_attr (raid_device, "md/sync_completed", NULL);
-          bitmap_location = udisks_linux_device_read_sysfs_attr (raid_device, "md/bitmap/location", NULL);
+          consistency_policy = udisks_linux_device_read_sysfs_attr (raid_device, "md/consistency_policy", NULL);
+          devfile = g_udev_device_get_device_file (raid_device->udev_device);
+          if (devfile)
+            bitmap_location = bd_md_get_bitmap_location (devfile, NULL);
         }
 
       if (mdraid_has_stripes (level))
@@ -326,6 +331,7 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
     }
   udisks_mdraid_set_degraded (iface, degraded);
   udisks_mdraid_set_sync_action (iface, sync_action);
+  udisks_mdraid_set_consistency_policy (iface, consistency_policy);
   udisks_mdraid_set_bitmap_location (iface, bitmap_location);
   udisks_mdraid_set_chunk_size (iface, chunk_size);
 
@@ -368,7 +374,8 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
                                                  UDISKS_OBJECT (object),
                                                  sync_action_to_job_id (sync_action),
                                                  0,
-                                                 NULL /* cancellable */);
+                                                 TRUE, /* no_inhibit */
+                                                 NULL  /* cancellable */);
 
           /* Mark the job as not cancellable. It simply has to finish... */
           udisks_job_set_cancelable (UDISKS_JOB (job), FALSE);
@@ -517,6 +524,7 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
       bd_md_examine_data_free (raid_data);
   g_free (sync_completed);
   g_free (sync_action);
+  g_free (consistency_policy);
   g_free (bitmap_location);
   g_list_free_full (member_devices, g_object_unref);
   g_clear_object (&raid_device);
@@ -639,6 +647,7 @@ handle_start (UDisksMDRaid           *_mdraid,
                                          UDISKS_OBJECT (object),
                                          "md-raid-start",
                                          caller_uid,
+                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -801,6 +810,7 @@ udisks_linux_mdraid_stop (UDisksMDRaid           *_mdraid,
                                          UDISKS_OBJECT (object),
                                          "md-raid-stop",
                                          caller_uid,
+                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -1022,6 +1032,7 @@ handle_remove_device (UDisksMDRaid           *_mdraid,
                                          UDISKS_OBJECT (object),
                                          "md-raid-remove-device",
                                          caller_uid,
+                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -1166,6 +1177,7 @@ handle_add_device (UDisksMDRaid           *_mdraid,
                                          UDISKS_OBJECT (object),
                                          "md-raid-add-device",
                                          caller_uid,
+                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -1282,6 +1294,7 @@ handle_set_bitmap_location (UDisksMDRaid           *_mdraid,
                                          UDISKS_OBJECT (object),
                                          "md-raid-set-bitmap",
                                          caller_uid,
+                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -1329,6 +1342,7 @@ handle_request_sync_action (UDisksMDRaid           *_mdraid,
   GError *error = NULL;
   const gchar *device_file = NULL;
   UDisksBaseJob *job = NULL;
+  gboolean opt_no_inhibit = FALSE;
 
   object = udisks_daemon_util_dup_object (mdraid, &error);
   if (object == NULL)
@@ -1359,6 +1373,8 @@ handle_request_sync_action (UDisksMDRaid           *_mdraid,
       goto out;
     }
 
+  g_variant_lookup (options, "no-inhibit-lock", "b", &opt_no_inhibit);
+
   raid_device = udisks_linux_mdraid_object_get_device (object);
   if (raid_device == NULL)
     {
@@ -1399,6 +1415,7 @@ handle_request_sync_action (UDisksMDRaid           *_mdraid,
                                          UDISKS_OBJECT (object),
                                          sync_action_to_job_id (sync_action),
                                          caller_uid,
+                                         opt_no_inhibit,
                                          NULL);
 
   if (job == NULL)
